@@ -102,31 +102,31 @@ flex_mode_base <- function(
     axis.ticks.length.y = NULL,
     axis.ticks.length.y.left = NULL,
     axis.ticks.length.y.right = NULL,
-    axis.title = ggplot2::element_text(size = base_size, colour = base_colour),
-    axis.title.x = ggplot2::element_text(margin = ggplot2::margin(t = base_size * -0.33, r = 0, b = base_size * 0.75, l = 0)),
-    axis.title.x.top = ggplot2::element_text(margin = ggplot2::margin(t = base_size * -1, r = 0, b = base_size * 1, l = 0)),
-    axis.title.y = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = base_size * 1, b = 0, l = 0), angle = 90),
-    axis.title.y.right = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = base_size * -0.5, b = 0, l = base_size * 1), angle = -90),
-    axis.text = ggplot2::element_text(size = base_size, colour = base_colour),
-    axis.text.y = ggplot2::element_text(margin = ggplot2::margin(r = base_size * 0.25), hjust = 1),
-    axis.text.y.right = ggplot2::element_text(margin = ggplot2::margin(l = base_size * 0.25), hjust = 0),
-    axis.text.x = ggplot2::element_text(vjust = 1, margin = ggplot2::margin(t = base_size * 0.3, r = 0, b = base_size * 1, l = 0)),
-    axis.text.x.top = ggplot2::element_text(vjust = 0, margin = ggplot2::margin(t = base_size * -0.5, r = 0, b = base_size * 0.3, l = 0)),
+    axis.title = ggplot2::element_text(),
+    axis.title.x = ggplot2::element_text(margin = ggplot2::margin(t = 11 * -0.33, r = 0, b = 11 * 0.75, l = 0)),
+    axis.title.x.top = ggplot2::element_text(margin = ggplot2::margin(t = 11 * -1, r = 0, b = 11 * 1, l = 0)),
+    axis.title.y = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = 11 * 1, b = 0, l = 0), angle = 90),
+    axis.title.y.right = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = 11 * -0.5, b = 0, l = 11 * 1), angle = -90),
+    axis.text = ggplot2::element_text(),
+    axis.text.y = ggplot2::element_text(margin = ggplot2::margin(r = 11 * 0.25), hjust = 1),
+    axis.text.y.right = ggplot2::element_text(margin = ggplot2::margin(l = 11 * 0.25), hjust = 0),
+    axis.text.x = ggplot2::element_text(vjust = 1, margin = ggplot2::margin(t = 11 * 0.3, r = 0, b = 11 * 1, l = 0)),
+    axis.text.x.top = ggplot2::element_text(vjust = 0, margin = ggplot2::margin(t = 11 * -0.5, r = 0, b = 11 * 0.3, l = 0)),
 
-    legend.margin = ggplot2::margin(t = 0, r = base_size * -1, b = base_size * 0.75, l = base_size * 0.75),
-    legend.spacing = grid::unit(base_size * 1, "pt"),
-    legend.spacing.y = grid::unit(base_size * 1.5, "pt"),
+    legend.margin = ggplot2::margin(t = 0, r = 11 * -1, b = 11 * 0.75, l = 11 * 0.75),
+    legend.spacing = grid::unit(11 * 1, "pt"),
+    legend.spacing.y = grid::unit(11 * 1.5, "pt"),
     legend.spacing.x = NULL,
     legend.key = ggplot2::element_rect(colour = legend_key_fill, fill = legend_key_fill),
-    legend.key.size = grid::unit(base_size * 1.75, "pt"),
+    legend.key.size = grid::unit(11 * 12/11, "pt"),
     legend.key.height = NULL,
     legend.key.width = NULL,
     legend.key.spacing = NULL,
-    legend.key.spacing.x = grid::unit(base_size, "pt"),
-    legend.key.spacing.y = grid::unit(base_size * 0.33, "pt"),
+    legend.key.spacing.x = grid::unit(11, "pt"),
+    legend.key.spacing.y = grid::unit(11 * 0.33, "pt"),
     legend.byrow = FALSE,
     legend.frame = NULL,
-    legend.text = ggplot2::element_text(size = base_size, colour = base_colour, margin = ggplot2::margin(5.5, 5.5, 5.5, 5.5)),
+    legend.text = ggplot2::element_text(margin = ggplot2::margin(5.5, 5.5, 5.5, 5.5)),
     legend.axis.line = ggplot2::element_line(colour = legend_axis_line_colour, linewidth = legend_axis_line_linewidth),
     legend.ticks = ggplot2::element_line(colour = legend_ticks_colour, linewidth = legend_ticks_linewidth),
     legend.ticks.length = legend_ticks_length,
@@ -145,17 +145,17 @@ flex_mode_base <- function(
     panel.grid.minor = ggplot2::element_blank(),
     panel.grid.minor.x = NULL,
     panel.grid.minor.y = NULL,
-    panel.spacing = grid::unit(base_size * 2, "pt"),
+    panel.spacing = grid::unit(11 * 2, "pt"),
     panel.spacing.x = NULL,
     panel.spacing.y = NULL,
     panel.ontop = FALSE,
     strip.background = ggplot2::element_rect(fill = NA, colour = NA),
     strip.clip = "off",
-    strip.text = ggplot2::element_text(size = base_size, colour = base_colour, margin = ggplot2::margin(t = 0, r = 0, b = base_size * 0.66, l = 0)),
+    strip.text = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = 0, b = 11 * 0.66, l = 0)),
     strip.text.x = NULL,
-    strip.text.x.bottom = ggplot2::element_text(margin = ggplot2::margin(t = base_size * 0.25, r = 0, b = base_size * 1, l = 0)),
-    strip.text.y = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = 0, b = 0, l = base_size * 2/3), angle = -90),
-    strip.text.y.left = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = base_size * 2/3, b = 0, l = 0), angle = 90),
+    strip.text.x.bottom = ggplot2::element_text(margin = ggplot2::margin(t = 11 * 0.25, r = 0, b = 11 * 1, l = 0)),
+    strip.text.y = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = 0, b = 0, l = 11 * 2/3), angle = -90),
+    strip.text.y.left = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = 11 * 2/3, b = 0, l = 0), angle = 90),
     strip.placement = "outside",
     strip.placement.x = NULL,
     strip.placement.y = NULL,
@@ -163,24 +163,24 @@ flex_mode_base <- function(
     strip.switch.pad.wrap = grid::unit(0.15, "pt"),
     plot.background = ggplot2::element_rect(colour = plot_background_fill, fill = plot_background_fill),
     plot.title = ggplot2::element_text(size = plot_title_size, family = plot_title_family, face = plot_title_face, colour = plot_title_colour,
-                                       hjust = 0, margin = ggplot2::margin(t = base_size * -1, r = 0, b = base_size * 2.5, l = 0)),
+                                       hjust = 0, margin = ggplot2::margin(t = 11 * -1, r = 0, b = 11 * 2.5, l = 0)),
     plot.title.position = "plot",
     plot.subtitle = ggplot2::element_text(size = plot_subtitle_size, family = plot_subtitle_family, face = plot_subtitle_face, colour = plot_subtitle_colour,
-                                          hjust = 0, margin = ggplot2::margin(t = base_size * -2, r = 0, b = base_size * 2, l = 0)),
+                                          hjust = 0, margin = ggplot2::margin(t = 11 * -2, r = 0, b = 11 * 2, l = 0)),
     plot.caption = ggplot2::element_text(size = plot_caption_size, family = plot_caption_family, face = plot_caption_face, colour = plot_caption_colour, hjust = plot_caption_hjust,
-                                         margin = ggplot2::margin(t = base_size * 0.5, r = 0, b = base_size * 0.5, l = 0)),
+                                         margin = ggplot2::margin(t = 11 * 0.5, r = 0, b = 11 * 0.5, l = 0)),
     plot.caption.position = "plot",
     plot.tag = ggplot2::element_text(size = ggplot2::rel(1.2), hjust = 0, vjust = 0.5),
     plot.tag.position = "topleft",
-    plot.margin = ggplot2::margin(t = base_size * 2, r = base_size * 2, b = base_size * 0.33, l = base_size * 1),
+    plot.margin = ggplot2::margin(t = 11 * 2, r = 11 * 2, b = 11 * 0.33, l = 11 * 1),
     legend.position = "right",
     legend.direction = "vertical",
     legend.justification = c(0, 1),
     legend.location = "panel",
     legend.box.margin = ggplot2::margin(t = 0, r = 0, b = 0, l = 0),
-    legend.title = ggplot2::element_text(size = base_size, colour = base_colour, margin = ggplot2::margin(t = 0, r = 0, b = base_size * 0.5, l = 0)),
+    legend.title = ggplot2::element_text(margin = ggplot2::margin(t = 0, r = 0, b = 11 * 0.5, l = 0)),
 
-    complete = FALSE
+    complete = TRUE
   )
 
   return(theme)
