@@ -3,7 +3,7 @@ testthat::skip_on_os(c("mac", "linux"))
 
 library(palmerpenguins)
 library(ggplot2)
-set_blanket(geom_colour = "#121b24")
+set_blanket(colour = "#121b24")
 
 test_name <- "light_mode_r"
 
@@ -62,23 +62,4 @@ test_that(test_name, {
   vdiffr::expect_doppelganger(test_name, p)
 })
 
-test_name <- "light_mode_n"
-
-test_that(test_name, {
-  set.seed(123)
-
-  p <- penguins |>
-    gg_point(
-      x = flipper_length_mm,
-      y = island,
-      col = bill_depth_mm,
-      facet = sex,
-      mapping = aes(alpha = species, shape = species),
-      mode = light_mode_n()
-    ) +
-    scale_alpha_manual(values = c(1, 1, 0.33))
-
-  vdiffr::expect_doppelganger(test_name, p)
-})
-
 set_blanket()
